/*
 * StationDetail.h
 *
 *  Created on: Nov 3, 2010
 *      Author: Thomas Schwery
 */

#ifndef STATIONDETAIL_H_
#define STATIONDETAIL_H_

#include <QtGui>
#include "Station.h"
#include "mapwidget.h"
#include "gpsposition.h"

#include <QGeoPositionInfo>
#include <QGeoCoordinate>

QTM_USE_NAMESPACE;

class StationDetail : public QWidget {
    Q_OBJECT;
public:
    StationDetail(Station * station, QWidget *parent = 0);
    virtual ~StationDetail();
};

#endif /* STATIONDETAIL_H_ */
